//*****************************************************************************
// File Name	: main.c
// 
// Titel		: Masterclass hoofdprogramma
// Revisie		: 1.0
//
// Revision History:
// When			Who			Description of change
// -----------	-----------	-----------------------
// 10-Sep-2002	pstang		Created the program
// 05-Mrt-2007  e13			Aanpassing voor masterclass
//*****************************************************************************

//----- Include Files ---------------------------------------------------------
#include <avr/io.h>		// include I/O definitions (port names, pin names, etc)
//#include <avr/signal.h>	// include "signal" names (interrupt names)
#include <avr/interrupt.h>	// include interrupt support

#include "global.h"		// include our global settings
#include "uart.h"		// include uart function library
#include "rprintf.h"	// include printf function library
#include "a2d.h"		// include A/D converter function library
#include "timer.h"		// include timer function library (timing, PWM, etc)
#include "vt100.h"		// include VT100 terminal library
#include "servo.h"

void Timer0Overflow(void);
volatile char fastcount;
volatile char kookwekker;
volatile char obstacledetect =TRUE;
volatile char pos1,pos2;
volatile char i=0;
volatile int z;

#define STOP 0
#define FORWARD 1
#define BACKWARD 2

typedef struct 
	{
	char leftfront;
	char rightfront;
	char centre;
	char leftrear;
	char rightrear;
	} programinstruction;
programinstruction walk_forwards[] =    {
	100,100,75,150,150,
	100,100,105,150,150,
	150,150,135,100,100,
	150,150,105,100,100
	};
programinstruction walk_backwards[] =    {
	150,150,105,100,100,
	150,150,135,100,100,
	100,100,105,150,150,
	100,100,75,150,150,
	};

int main(void)				// hoofdprogramma
{
	char n,move;					// tijdelijke variabele (0 tot 255)
	int c,step;
	outb(DDRB,0x01);
	outb(PORTB,0x00);
	outb(PORTC,0xff);
	outb(DDRC,0x00);
	// initialize our libraries
	// initialize the UART (serial port)
	uartInit();
	// set the baud rate of the UART for our debug/reporting output
	uartSetBaudRate(9600);
	// set uartSendByte as the output for all rprintf statements
	rprintfInit(uartSendByte);
	// initialize the timer system
	timerInit();
	// initialize vt100 library
	vt100Init();
	// initialize cmdline system
	// turn on and initialize A/D converter
	a2dInit();
	// set the a2d prescaler (clock division ratio)
	// - a lower prescale setting will make the a2d converter go faster
	// - a higher setting will make it go slower but the measurements
	//   will be more accurate
	// - other allowed prescale values can be found in a2d.h
	a2dSetPrescaler(ADC_PRESCALE_DIV32);
	// set the a2d reference
	// - the reference is the voltage against which a2d measurements are made
	// - other allowed reference values can be found in a2d.h
	a2dSetReference(ADC_REFERENCE_AVCC);
	// use a2dConvert8bit(channel#) to get an 8bit a2d reading
	// use a2dConvert10bit(channel#) to get a 10bit a2d reading
//     timer0SetPrescaler(TIMER_CLK_DIV64);
//	TCNT0=0xce; //5000Hz @ 64 - 16MHz
//	timerAttach(TIMER0OVERFLOW_INT, Timer0Overflow);
	
	sei();

	// initialize RC servo system
	servoInit();
	// setup servo output channel-to-I/Opin mapping
	// format is servoSetChannelIO( CHANNEL#, PORT, PIN );
	servoSetChannelIO(0, _SFR_IO_ADDR(PORTB), PB1);
	servoSetChannelIO(1, _SFR_IO_ADDR(PORTB), PB2);
	servoSetChannelIO(2, _SFR_IO_ADDR(PORTB), PB3);
	servoSetChannelIO(3, _SFR_IO_ADDR(PORTB), PB4);
	servoSetChannelIO(4, _SFR_IO_ADDR(PORTB), PB5);


	// set port pins to output
	outb(DDRB, 0xFF);
	
    vt100ClearScreen();
	// print a little intro message so we know things are working
	rprintf("\r\nbroem\r\n");
	move = FORWARD;
	while(1)				// altijd waar, deze lus draait altijd door
	{
		if(!(PINC&0x04) || !(PINC&0x10))
		{	
			step=0;
			move = BACKWARD;
		}
		if (move==BACKWARD && step >10)
		{
			move = FORWARD;
		}

		if(move==FORWARD)
		{
			for (n=0;n<4;n++)
			{
				servoSetPosition(3,walk_forwards[n].leftfront);
				servoSetPosition(2,walk_forwards[n].rightfront);
				servoSetPosition(0,walk_forwards[n].centre);
				servoSetPosition(4,walk_forwards[n].leftrear);
				servoSetPosition(1,walk_forwards[n].rightrear);
				if(!(PINC&0x04) || !(PINC&0x10)) break;
				delay_ms(a2dConvert10bit(1));
				step++;
			}	
		}
		else if(move==BACKWARD)
		{
			for (n=0;n<4;n++)
			{
				servoSetPosition(3,walk_backwards[n].leftfront);
				servoSetPosition(2,walk_backwards[n].rightfront);
				servoSetPosition(0,walk_backwards[n].centre);
				servoSetPosition(4,walk_backwards[n].leftrear);
				servoSetPosition(1,walk_backwards[n].rightrear);
				delay_ms(a2dConvert10bit(1));
				step++;
			}	
		}
		else if(move==STOP)
		{
			servoSetPosition(3,127);
			servoSetPosition(2,127);
			servoSetPosition(0,105);
			servoSetPosition(4,127);
			servoSetPosition(1,127);
		}
		
	}
	return 0;
}

// ----------------------------------------------------------------------------

void Timer0Overflow(void)
{
TCNT0=0xce;	//5000 hz

fastcount++;
if (fastcount>99)
	{
	kookwekker=1;
	fastcount=0;
	}
}

